@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-import logging
 from .sqlparse import SQLAnalyze
 from .sqlparse import SQLFormatWithPrefix
 from .commandanalyze import execute
@@ -7,9 +6,6 @@ from .commandanalyze import CommandNotFound
 from .sqlcliexception import SQLCliException
 import click
 import time
-import os
-
-_logger = logging.getLogger(__name__)
 
 
 class SQLExecute(object):
@@ -18,6 +14,9 @@ class SQLExecute(object):
     logfile = None                      # 打印的日志文件
     sqlscript = None                    # 需要执行的SQL脚本
     SQLMappingHandler = None            # SQL重写处理
+    m_Current_RunningSQL = None         # 目前程序运行的当前SQL
+    m_Current_RunningStarted = None     # 目前程序运行的当前SQL开始时间
+    NoConsole = False                   # 屏幕输出Console，如果为True, 不再输出屏幕信息
 
     def __init__(self):
         # 设置一些默认的参数
@@ -25,6 +24,9 @@ class SQLExecute(object):
                         "LONG": 20, 'KAFKA_SERVERS': None, 'TIMING': 'OFF', 'TERMOUT': 'ON', 'FEEDBACK': 'ON',
                         "ARRAYSIZE": 10000, 'SQLREWRITE': 'ON', "DEBUG": 'OFF'}
 
+    def set_logfile(self, p_logfile):
+        self.logfile = p_logfile
+
     def set_connection(self, p_conn):
         self.conn = p_conn
 
@@ -52,7 +54,8 @@ class SQLExecute(object):
 
             # 如果运行在脚本模式下，需要在控制台回显SQL
             if self.sqlscript is not None:
-                click.secho(SQLFormatWithPrefix(m_CommentSQL))
+                if not self.NoConsole:
+                    click.secho(SQLFormatWithPrefix(m_CommentSQL))
 
             # 如果打开了回显，并且指定了输出文件，且SQL被改写过，输出改写后的SQL
             if self.options["SQLREWRITE"] == 'ON':
@@ -64,35 +67,21 @@ class SQLExecute(object):
                         click.echo(SQLFormatWithPrefix(
                             "Your SQL has been changed to:\n" + sql, 'REWROTED '), file=self.logfile)
                     if self.sqlscript is not None:
-                        click.secho(SQLFormatWithPrefix(
-                            "Your SQL has been changed to:\n" + sql, 'REWROTED '))
+                        if not self.NoConsole:
+                            click.secho(SQLFormatWithPrefix(
+                                "Your SQL has been changed to:\n" + sql, 'REWROTED '))
 
             # 如果是空语句，不在执行
             if len(sql.strip()) == 0:
                 continue
 
-            # 在没有数据库连接的时候，必须先加载驱动程序，连接数据库
-            if not self.conn and not (
-                sql.startswith("loaddriver")
-                or sql.startswith("loadsqlmap")
-                or sql.startswith("connect")
-                or sql.startswith("start")
-                or sql.startswith("__internal__")
-                or sql.startswith("help")
-                or sql.startswith("exit")
-                or sql.startswith("quit")
-                or sql.startswith("set")
-            ):
-                if self.options["WHENEVER_SQLERROR"] == "EXIT":
-                    raise SQLCliException("Not Connected. ")
-                else:
-                    yield None, None, None, "Not connected. "
-
             # 打开游标
             cur = self.conn.cursor() if self.conn else None
 
             # 记录命令开始时间
             start = time.time()
+            self.m_Current_RunningSQL = sql
+            self.m_Current_RunningStarted = start
 
             # 执行SQL
             try:
@@ -100,21 +89,23 @@ class SQLExecute(object):
                 for result in execute(cur, sql):
                     yield result
             except CommandNotFound:
+                if cur is None:
+                    # 进入到SQL执行阶段，但是没有conn，也不是特殊命令
+                    if self.options["WHENEVER_SQLERROR"] == "EXIT":
+                        raise SQLCliException("Not Connected. ")
+                    else:
+                        yield None, None, None, "Not connected. "
+
                 # 执行正常的SQL语句
                 if cur is not None:
                     try:
-                        if "SQLCLI_DEBUG" in os.environ:
-                            print("DEBUG:: Execute SQL > [" + sql + "]")
                         cur.execute(sql)
-                        if "SQLCLI_DEBUG" in os.environ:
-                            print("DEBUG:: Fetch Result> [" + sql + "]")
-
                         rowcount = 0
                         while True:
                             (title, result, headers, status, m_FetchStatus, m_FetchedRows) = \
                                 self.get_result(cur, rowcount)
                             rowcount = m_FetchedRows
-                            yield title,result,headers,status
+                            yield title, result, headers, status
                             if not m_FetchStatus:
                                 break
                     except Exception as e:
@@ -138,11 +129,20 @@ class SQLExecute(object):
 
             # 记录结束时间
             end = time.time()
+            self.m_Current_RunningSQL = None
+            self.m_Current_RunningStarted = None
+
             # 如果需要，打印语句执行时间
             if self.options['TIMING'] == 'ON':
                 if sql.strip().upper() not in ('EXIT', 'QUIT'):
                     yield None, None, None, 'Running time elapsed: %8.2f Seconds' % (end - start)
 
+    def get_Current_RunningSQL(self):
+        return self.m_Current_RunningSQL
+
+    def get_Current_RunningStarted(self):
+        return self.m_Current_RunningStarted
+
     def get_result(self, cursor, rowcount):
         """Get the current result's data from the cursor."""
         title = headers = None
@@ -166,7 +166,7 @@ class SQLExecute(object):
                             m_row.append(column)
                     m_row = tuple(m_row)
                     result.append(m_row)
-                    rowcount = rowcount + 1
+            rowcount = rowcount + len(rowset)
             if len(rowset) < m_arraysize:
                 # 已经没有什么可以取的了, 游标结束
                 m_FetchStatus = False
